@@ -1,4 +1,4 @@
-# Copyright (C) 2021,2022 Kian-Meng Ang
+# Copyright (C) 2021,2022,2023 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -18,5 +18,5 @@
 from txt2ebook.txt2ebook import main
 
 if __name__ == "__main__":
-    main()  # pragma: no cover
-    raise SystemExit()  # pragma: no cover
+    main()
+    raise SystemExit()
