@@ -1,4 +1,4 @@
-# Copyright (C) 2021,2022 Kian-Meng Ang
+# Copyright (C) 2021,2022,2023 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -17,10 +17,6 @@
 
 DEFAULT_RE_TITLE = r"Title:(.*)"
 DEFAULT_RE_AUTHOR = r"Author:(.*)"
-DEFAULT_RE_VOLUME_CHAPTER = r"(^Volume.*)[ ]*Chapter.*$"
-DEFAULT_RE_VOLUME = "^Volume.*$"
-DEFAULT_RE_CHAPTER = "^Chapter.*$"
-
-STRUCTURE_NAMES = {
-    "cover": "Cover",
-}
+DEFAULT_RE_TAG = r"Tags：(.*)"
+DEFAULT_RE_VOLUME = r"(Volume.*)"
+DEFAULT_RE_CHAPTER = r"(Chapter.*)"
