@@ -26,7 +26,7 @@ import regex as re
 
 from txt2ebook.models import Book, Chapter, Volume
 from txt2ebook.tokenizer import Tokenizer
-from txt2ebook.zh_utils import zh_halfwidth_to_fullwidth, zh_numeric, zh_words_to_numbers
+from txt2ebook.zh_utils import zh_halfwidth_to_fullwidth, zh_words_to_numbers
 
 logger = logging.getLogger(__name__)
 
@@ -123,7 +123,7 @@ class Parser:
                 header_nums, str(header_nums).rjust(length, "０")
             )
 
-        replaced_words = zh_words_to_numbers(words, length)
+        replaced_words = zh_words_to_numbers(words, length=length)
 
         if self.fullwidth:
             replaced_words = zh_halfwidth_to_fullwidth(replaced_words)
@@ -135,7 +135,6 @@ class Parser:
         )
         return replaced_words
 
-
     def parse_tokens(self, tokenizer: Tokenizer) -> Tuple:
         """Parse the tokens and organize into book structure."""
         toc: List[Union[Volume, Chapter]] = []
